import { formatOutput } from "../converters/lintConfigs/formatting/formatOutput";
import { joinConfigConversionResults, } from "../converters/lintConfigs/joinConfigConversionResults";
import { ResultStatus, } from "../types";
import { createESLintConfigurationStandalone } from "./createESLintConfigurationStandalone";
import { findOriginalConfigurationsStandalone } from "./findOriginalConfigurationsStandalone";
/**
 * Finds relevant configurations on disk and outputs the generated ESLint configuration.
 *
 * @param settings - Settings to find and convert configurations to an ESLint configuration.
 */
export const convertTSLintConfigStandalone = async (rawSettings = {}) => {
    const settings = {
        ...rawSettings,
        config: ".eslintrc.js",
    };
    const originalConfigurations = await findOriginalConfigurationsStandalone(settings);
    if (originalConfigurations.status !== ResultStatus.Succeeded) {
        return originalConfigurations;
    }
    const summarizedConfiguration = await createESLintConfigurationStandalone(originalConfigurations.data, settings.prettier);
    const output = joinConfigConversionResults(summarizedConfiguration, originalConfigurations.data);
    return {
        data: {
            formatted: formatOutput(settings.config, output),
            raw: output,
        },
        status: ResultStatus.Succeeded,
    };
};
//# sourceMappingURL=convertTSLintConfigStandalone.js.map