import { childProcessExec } from "../adapters/childProcessExec";
import { fsFileSystem } from "../adapters/fsFileSystem";
import { globAsync } from "../adapters/globAsync";
import { nativeImporter } from "../adapters/nativeImporter";
import { processLogger } from "../adapters/processLogger";
import { bind } from "../binding";
import { collectCommentFileNames, } from "../comments/collectCommentFileNames";
import { convertComments, } from "../converters/comments/convertComments";
import { convertFileComments, } from "../converters/comments/convertFileComments";
import { extractGlobPaths, } from "../converters/comments/extractGlobPaths";
import { reportCommentResults, } from "../converters/comments/reporting/reportCommentResults";
import { convertEditorConfig, } from "../converters/editorConfigs/convertEditorConfig";
import { convertEditorConfigs, } from "../converters/editorConfigs/convertEditorConfigs";
import { convertAtomConfig } from "../converters/editorConfigs/converters/convertAtomConfig";
import { convertVSCodeConfig } from "../converters/editorConfigs/converters/convertVSCodeConfig";
import { reportEditorConfigConversionResults } from "../converters/editorConfigs/reporting/reportEditorConfigConversionResults";
import { convertLintConfig, } from "../converters/lintConfigs/convertLintConfig";
import { createESLintConfiguration, } from "../converters/lintConfigs/createESLintConfiguration";
import { removeExtendsDuplicatedRules } from "../converters/lintConfigs/pruning/removeExtendsDuplicatedRules";
import { choosePackageManager, } from "../converters/lintConfigs/reporting/packages/choosePackageManager";
import { logMissingPackages, } from "../converters/lintConfigs/reporting/packages/logMissingPackages";
import { reportConfigConversionResults, } from "../converters/lintConfigs/reporting/reportConfigConversionResults";
import { convertRules, } from "../converters/lintConfigs/rules/convertRules";
import { ruleConverters } from "../converters/lintConfigs/rules/ruleConverters";
import { ruleMergers } from "../converters/lintConfigs/rules/ruleMergers";
import { checkPrettierExtension } from "../converters/lintConfigs/summarization/prettier/checkPrettierExtension";
import { retrieveExtendsValues, } from "../converters/lintConfigs/summarization/retrieveExtendsValues";
import { summarizePackageRules, } from "../converters/lintConfigs/summarization/summarizePackageRules";
import { findESLintConfiguration } from "../input/findESLintConfiguration";
import { findOriginalConfigurations, } from "../input/findOriginalConfigurations";
import { findPackagesConfiguration } from "../input/findPackagesConfiguration";
import { findTSLintConfiguration } from "../input/findTSLintConfiguration";
import { findTypeScriptConfiguration } from "../input/findTypeScriptConfiguration";
import { importer } from "../input/importer";
import { mergeLintConfigurations } from "../input/mergeLintConfigurations";
export const convertFileCommentsDependencies = {
    converters: ruleConverters,
    fileSystem: fsFileSystem,
};
export const reportCommentResultsDependencies = {
    logger: processLogger,
};
export const convertRulesDependencies = {
    ruleConverters,
    ruleMergers,
};
export const nativeImporterDependencies = {
    fileSystem: fsFileSystem,
    getCwd: () => process.cwd(),
    nativeImporter: nativeImporter,
};
export const boundImporter = bind(importer, nativeImporterDependencies);
export const findConfigurationDependencies = {
    exec: childProcessExec,
    importer: boundImporter,
    platform: process.platform,
};
export const findOriginalConfigurationsDependencies = {
    findESLintConfiguration: bind(findESLintConfiguration, findConfigurationDependencies),
    findPackagesConfiguration: bind(findPackagesConfiguration, findConfigurationDependencies),
    findTypeScriptConfiguration: bind(findTypeScriptConfiguration, findConfigurationDependencies),
    findTSLintConfiguration: bind(findTSLintConfiguration, findConfigurationDependencies),
    mergeLintConfigurations,
};
export const collectCommentFileNamesDependencies = {
    findTypeScriptConfiguration: bind(findTypeScriptConfiguration, findConfigurationDependencies),
};
export const extractGlobPathsDependencies = {
    globAsync,
};
export const convertCommentsDependencies = {
    collectCommentFileNames: bind(collectCommentFileNames, collectCommentFileNamesDependencies),
    convertFileComments: bind(convertFileComments, convertFileCommentsDependencies),
    extractGlobPaths: bind(extractGlobPaths, extractGlobPathsDependencies),
    reportCommentResults: bind(reportCommentResults, reportCommentResultsDependencies),
};
export const retrieveExtendsValuesDependencies = {
    importer: boundImporter,
};
export const summarizePackageRulesDependencies = {
    checkPrettierExtension,
    removeExtendsDuplicatedRules,
    retrieveExtendsValues: bind(retrieveExtendsValues, retrieveExtendsValuesDependencies),
};
export const choosePackageManagerDependencies = {
    fileSystem: fsFileSystem,
};
export const createESLintConfigurationDependencies = {
    convertRules: bind(convertRules, convertRulesDependencies),
    summarizePackageRules: bind(summarizePackageRules, summarizePackageRulesDependencies),
};
export const logMissingPackagesDependencies = {
    choosePackageManager: bind(choosePackageManager, choosePackageManagerDependencies),
    logger: processLogger,
};
export const reportConversionResultsDependencies = {
    logger: processLogger,
};
export const reportEditorSettingConversionResultsDependencies = {
    logger: processLogger,
};
export const writeConversionResultsDependencies = {
    fileSystem: fsFileSystem,
};
export const convertEditorConfigDependencies = {
    fileSystem: fsFileSystem,
};
export const editorConfigDescriptors = [
    [".atom/config.cson", convertAtomConfig],
    [".vscode/settings.json", convertVSCodeConfig],
];
export const reportEditorConfigConversionResultsDependencies = {
    logger: processLogger,
};
export const convertEditorConfigsDependencies = {
    convertEditorConfig: bind(convertEditorConfig, convertEditorConfigDependencies),
    editorConfigDescriptors,
    reportEditorConfigConversionResults: bind(reportEditorConfigConversionResults, reportEditorConfigConversionResultsDependencies),
};
export const convertLintConfigDependencies = {
    createESLintConfiguration: bind(createESLintConfiguration, createESLintConfigurationDependencies),
    fileSystem: fsFileSystem,
    logMissingPackages: bind(logMissingPackages, logMissingPackagesDependencies),
    reportConfigConversionResults: bind(reportConfigConversionResults, reportConversionResultsDependencies),
};
export const runCliDependencies = {
    converters: [
        bind(convertLintConfig, convertLintConfigDependencies),
        bind(convertEditorConfigs, convertEditorConfigsDependencies),
        bind(convertComments, convertCommentsDependencies),
    ],
    findOriginalConfigurations: bind(findOriginalConfigurations, findOriginalConfigurationsDependencies),
    logger: processLogger,
};
//# sourceMappingURL=dependencies.js.map