import * as utils from "tsutils";
import ts from "typescript";
/**
 * @see https://github.com/Microsoft/TypeScript/issues/21049
 */
export const parseFileComments = (filePath, content) => {
    const sourceFile = ts.createSourceFile(filePath, content, ts.ScriptTarget.Latest, 
    /*setParentNodes */ true);
    const directives = [];
    utils.forEachComment(sourceFile, (fullText, comment) => {
        const parsedComment = parseFileComment(fullText, comment);
        if (parsedComment !== undefined) {
            directives.push(parsedComment);
        }
    });
    return directives;
};
/**
 * @see https://github.com/palantir/tslint/blob/master/src/enableDisableRules.ts
 */
const tslintRegex = new RegExp(/tslint:(enable|disable)(?:-(line|next-line))?(:|\s|$)/g);
const parseFileComment = (fullText, comment) => {
    const commentText = (comment.kind === ts.SyntaxKind.SingleLineCommentTrivia
        ? fullText.substring(comment.pos + 2, comment.end)
        : fullText.substring(comment.pos + 2, comment.end - 2)).trim();
    const match = commentText.match(tslintRegex);
    if (match === null) {
        return undefined;
    }
    return {
        commentKind: comment.kind,
        directive: match[0].replace("e:", "e"),
        end: comment.end,
        pos: comment.pos,
        ruleNames: commentText.slice(match[0].length).split(/\s+/).map(trimColons).filter(Boolean),
    };
};
const trimColons = (text) => text
    .replace(/^(:|\s)*/, "")
    .replace(/(:|\s)*$/, "")
    .trim();
//# sourceMappingURL=parseFileComments.js.map