import { removeEmptyMembers } from "../../utils";
import { createEnv } from "./eslint/createEnv";
import { formatConvertedRules } from "./formatConvertedRules";
/**
 * Turns a raw ESLint configuration summary into ESLint's configuration shape.
 */
export const joinConfigConversionResults = (summarizedResults, originalConfigurations) => {
    const plugins = new Set([...summarizedResults.plugins, "@typescript-eslint"]);
    const { eslint, tslint } = originalConfigurations;
    if (summarizedResults.missing.length !== 0) {
        plugins.add("@typescript-eslint/tslint");
    }
    return removeEmptyMembers({
        ...eslint === null || eslint === void 0 ? void 0 : eslint.full,
        env: createEnv(originalConfigurations),
        ...(eslint && { globals: eslint.raw.globals }),
        ...(summarizedResults.extends && { extends: summarizedResults.extends }),
        parser: "@typescript-eslint/parser",
        parserOptions: {
            project: "tsconfig.json",
            sourceType: "module",
        },
        plugins: Array.from(plugins),
        rules: formatConvertedRules(summarizedResults, tslint.full),
    });
};
//# sourceMappingURL=joinConfigConversionResults.js.map