import chalk from "chalk";
import { EOL } from "os";
import { isTruthy } from "../../../../utils";
import { installationMessages } from "./packageManagers";
export const logMissingPackages = async (dependencies, ruleConversionResults, packageConfiguration) => {
    var _a, _b;
    const packageManager = await dependencies.choosePackageManager();
    const existingPackageNames = new Set([
        ...Object.keys((_a = packageConfiguration === null || packageConfiguration === void 0 ? void 0 : packageConfiguration.dependencies) !== null && _a !== void 0 ? _a : {}),
        ...Object.keys((_b = packageConfiguration === null || packageConfiguration === void 0 ? void 0 : packageConfiguration.devDependencies) !== null && _b !== void 0 ? _b : {}),
    ]);
    const requiredPackageNames = [
        "@typescript-eslint/eslint-plugin",
        "@typescript-eslint/parser",
        ruleConversionResults.extends.join("").includes("prettier") && "eslint-config-prettier",
        ruleConversionResults.missing.length !== 0 && "@typescript-eslint/eslint-plugin-tslint",
        "eslint",
        ...Array.from(ruleConversionResults.plugins),
    ].filter(isTruthy);
    const missingPackageNames = requiredPackageNames
        .filter((packageName) => !existingPackageNames.has(packageName))
        .sort();
    if (missingPackageNames.length === 0) {
        return;
    }
    dependencies.logger.stdout.write(chalk.cyanBright(`${EOL}⚡ ${missingPackageNames.length}`));
    dependencies.logger.stdout.write(chalk.cyan(` new package${missingPackageNames.length === 1 ? " is" : "s are"} required for this ESLint configuration.`));
    dependencies.logger.stdout.write(chalk.cyanBright(" ⚡"));
    dependencies.logger.stdout.write(`${EOL}  `);
    dependencies.logger.stdout.write(chalk.cyan(installationMessages[packageManager](missingPackageNames.join(" "))));
    dependencies.logger.stdout.write(EOL);
};
//# sourceMappingURL=logMissingPackages.js.map