import { EOL } from "os";
export class ConversionError extends Error {
    constructor(summary) {
        super(summary);
        this.summary = summary;
    }
    static forMerger(eslintRule) {
        return new ConversionError([
            `Error: multiple output ${eslintRule} ESLint rule options were generated, but tslint-to-eslint-config doesn't have "merger" logic to deal with this.`,
            `Please file an issue at https://github.com/typescript-eslint/tslint-to-eslint-config/issues/new?template=missing_merger.md. Thanks!`,
        ].join(EOL));
    }
    static forRuleError(error, tslintRule) {
        return new ConversionError(`${tslintRule.ruleName} threw an error during conversion: ${error.stack}${EOL}`);
    }
    getSummary() {
        return this.summary;
    }
}
//# sourceMappingURL=conversionError.js.map