import * as path from "path";
import { parseJson } from "../utils";
export const importer = async (dependencies, moduleName) => {
    const pathAttempts = [path.join(dependencies.getCwd(), moduleName), moduleName];
    const importFile = async (filePath) => {
        if (!filePath.endsWith(".json")) {
            return await dependencies.nativeImporter(filePath);
        }
        if (!(await dependencies.fileSystem.fileExists(filePath))) {
            return undefined;
        }
        const rawJsonContents = await dependencies.fileSystem.readFile(filePath);
        if (rawJsonContents instanceof Error) {
            return rawJsonContents;
        }
        try {
            return parseJson(rawJsonContents);
        }
        catch (error) {
            return error;
        }
    };
    for (const pathAttempt of pathAttempts) {
        try {
            const result = await importFile(pathAttempt);
            if (result) {
                return result;
            }
        }
        catch (_a) { }
    }
    return new Error(`Could not find '${moduleName}' after trying: ${pathAttempts
        .map((attempt) => `'${attempt}'`)
        .join(", ")}`);
};
//# sourceMappingURL=importer.js.map