import JSON5 from "json5";
export const asError = (error) => (error instanceof Error ? error : new Error(`${error}`));
export const isDefined = (item) => item !== undefined;
export const isError = (item) => item instanceof Error;
export const isTruthy = (item) => !!item;
export const removeEmptyMembers = (items) => {
    const result = {};
    for (const [key, value] of Object.entries(items)) {
        if (!(value instanceof Array && value.length === 0) &&
            !(value instanceof Object && Object.keys(value).length === 0)) {
            result[key] = value;
        }
    }
    return result;
};
export const separateErrors = (mixed) => {
    const errors = [];
    const items = [];
    for (const item of mixed) {
        if (item instanceof Error) {
            errors.push(item);
        }
        else {
            items.push(item);
        }
    }
    return [errors, items];
};
export const uniqueFromSources = (...sources) => {
    const items = [];
    for (const source of sources) {
        if (source instanceof Array) {
            items.push(...source.filter(isDefined));
        }
        else if (source !== undefined) {
            items.push(source);
        }
    }
    return Array.from(new Set(items));
};
export const parseJson = (text) => JSON5.parse(text);
//# sourceMappingURL=utils.js.map